---
title: 계약 진행
category: 포트원 이용절차 (온보딩 가이드) > 전자결제 신청 > 계약 진행
seo:
  title: 계약 진행
  description: >-
    포트원 전자결제 신청을 위한 안내입니다. 계약은 PG사의 정책에 따라 진행되므로, PG사로부터 필요한 심사 양식과 계약서를
    안내받게됩니다. 아래 정보를 확인해보세요.
  keywords:
    - PG사 계약 진행
    - 전자결제 계약 진행
    - PG사 이용절차
    - 결제대행사
tags:
  - 공통
  - PG계약
  - 전자결제신청
pgCompanies:
  - 공통
searchTags:
  - 카드사심사
  - 수수료율
  - 수수료
  - 관리비
  - 가입비
  - 구비서류
  - 계약서
  - 보증보험가입
  - 입점심사
---

<Callout content="계약은 PG사의 정책에 따라 진행되므로, 모두 PG사로부터 필요한 심사 양식과 계약서를 안내받으시어 진행해주시기 바랍니다. 아래 내용부터는 모두 PG사로부터 직접 안내받으실 수 있는 내용입니다" />

### **입점심사**

결제대행사에서는 고객사와의 계약 전 고객사에서 운영하는 서비스 업종, 상품, 사이트 구현여부 등을 통해 입점심사를 진행합니다. 입점심사는 고객사의 사이트(혹은 앱서비스)를 기준으로 진행되므로 결제대행사에서 필수적으로 요구하는 항목은 미리 준비해두시는 것이 좋습니다.

입점심사의 기준은 결제대행사별로 크게 다르진 않으나 모두 결제대행사 내부 심사기준에 따라 결정이 되므로 정확한 결과는 해당 결제대행사를 통해 실제 심사를 받아보셔야지만 알 수 있습니다.

<Callout title="참고사항" content="**심사가 필요한 이유**
사업장에서 고객에게 서비스 이행을 하지 못하거나, 누군가 불순한 의도로 사업장의 서비스를 이용하여 불법적인 행위를 하는 경우, PG사에서는 결제 대금에 대한 배상의 책임을 지게되며 큰 손실을 감당하게 됩니다. PG사는 이 손실을 최소화 하기위해 입점 전 위험요소를 미리 파악하고 환불정책,이용약관등을 기재하여 리스크를 최소화 합니다." icon="💡" />

### **보증보험 가입**

보증보험은 결제대행사와의 계약 이후 사업장에서 발생할 수 있는 부도, 서비스 불이행 등으로 PG사에서 발생할 수 있는 피해를 대비하기 위한 보험입니다. 결제대행사와 계약시에는 반드시 보증보험 가입이 필요하며, 여러 PG사를 이용하신다면 결제대행사별로 가입해주셔야합니다. 보증보험 가입금액에 따라 배수 적용 시 월 정산한도가 따라서 적용 됩니다.

- 계약기간 : 1년 / 계약만료시 갱신절차 필요
- 가입방법 : 보증보험은 SGI서울보증보험을 통해 가입할 수 있으며, 결제대행사마다 자사의 보증보험을 취급하는 연계된 보험 대리점이 있어 결제대행사에서 안내되는 지점으로 직접 연락하여 가입할 수 있습니다. \
  지정된 대리점은 결제대행사 홈페이지나 계약시 결제대행사 계약담당자로부터 자세히 안내받으실 수 있습니다.
- 납부금액 : 결제대행사로부터 가입이 필요한 보증보험 금액을 안내받으실 수 있습니다. 보증보험금액은 가입하는 보험금액에 기준요율을 곱한 수수료를 납부하는 형식으로, 기준요율은 결제대행사별로 제공되는 이율이 다를 수 있으며, 기본적으로 **`0.953%`** 로 적용되고 있습니다.

<Callout icon="💡" title="참고사항" content="(예시)
- 일일정산(승인일+7일) : 월 정산한도 2배수 설정시
- 보증보험: 500만원 -> 월 정산한도 1,000만원

- 월 4회정산: 월 정산한도 3배수 설정시
- 보증보험: 500만원 -> 월 정산한도 1,500만원

- 월 2회정산: 월 정산한도 4배수 설정시
- 보증보험: 500만원 -> 월 정산한도 2,000만원

- 월 1회정산: 월 정산한도 5배수 설정시
- 보증보험: 500만원 -> 월 정산한도 2,500만원" />

### **계약서 및 구비서류 작성**

서류접수는 직접 우편물을 발송하거나 ‘전자계약'으로 인터넷상에서 간단히 업로드하는 방법이 있습니다.

필요한 구비서류 및 계약서는 신청하신 PG사에서 고객사의 담당자님 이메일로 상세히 안내 되고 있으며 서비스 유형 · 업종에 따라 결제대행사 내부 심사(RM)을 거쳐 추가 서류가 필요 할 수 있습니다. \
기본적으로 구비하실 서류는 아래표를 참고 해 주시기 바랍니다. (보증보험은 구매대행, 중고제품, 콘텐츠 등 쇼핑몰 업종이나 제품의 리스크, 단가와 같이 판매 아이템에 따라 달라질 수 있습니다.)

- **개인사업자**

<Indent level="1">

- PG사 계약서 2부
- 사업자등록증 사본 1부
- 정산받을 통장 계좌 사본 1부 (대표자 명의)
- 대표자 신분증 사본 1부
  - 내국인: 주민등록증(또는 운전면허증)
  - 외국인: 외국인등록증(또는 외국국적동포 국내거소신고증, 영주증)
    ※ 외국인등록증이 없을 경우 여권사본 제출
- 인감 증명서 원본 1부 (대표자 명의)
  - 주민등록번호 뒤 7자리는 마스킹 후 발송 (3개월 이내 발급분)
- (제출 필요시) 보증보험증권 (보증보험사에서 서류발송 대행)
  - 보증보험은 보증보험사로 직접 신청해주시기 바랍니다
- 소유자 확인서류 (고객거래확인서) 1부
  - 대표자외 대리인 작성시 각각 1부

</Indent>

- **법인사업자**

<Indent level="1">

- PG사 계약서 2부
- 사업자등록증 사본 1부
- 정산받을 통장 계좌 사본 1부 (법인 명의)
- 대표자 신분증 사본 1부
  - 내국인: 주민등록증(또는 운전면허증)
  - 외국인: 외국인등록증(또는 외국국적동포 국내거소신고증, 영주증)\
    ※ 외국인등록증이 없을 경우 여권사본 제출
- 법인인감증명서 원본 1부
  - 공동대표 모두 필요/3개월 이내 발급분
- 법인등기부등본 원본 1부
  - 3개월 이내 발급분
- 실제 소유자 확인가능 서류 1부
  - 주주명부(정관)
  - 출자자명부, 이사회명부, 사원명부 등
  - 지분 보유현황 자료\
    ※ 비영리법인의 경우 증빙서류 (정관/규약, 비영리법인 설립허가서 등) 1부
- (제출 필요시) 보증보험증권 (보증보험사에서 서류발송 대행)\
  ※ 보증보험은 보증보험사로 직접 신청해주시기 바랍니다.
- 사용인감계 1부
  - 법인의 경우 사용인감을 사용하였을 경우에 작성

</Indent>

- **특정 업종별 추가 준비 서류**

<Indent level="1">

- 주류 판매
  - 주류 제조 면허증/주류 통신판매 신고증
- 기부/후원
  - 정부인증된기관(기획재정부장관이 지정한 기부금 단체) 증빙 서류
- 모바일상품권(기프티콘)
  - 상품별 인지세 납부서류 혹은 위탁판매계약서
- 체육 시설(필라테스/헬스 이용권)
  - 영업필증
- 공유 오피스/임대업
  - 임대사업자 등록 및 적법한 임대차계약서 작성 확인 필요
  - 개별 임대차 계약서
  - 건축물 대장

</Indent>
